module C where

name :: String
name = "SamanthaC"
